@@ -2,6 +2,7 @@ from enum import Enum
 from typing import List, Optional
 
 from cloudrail.knowledge.context.aws.apigateway.api_gateway_method import ApiGatewayMethod
+from cloudrail.knowledge.context.aws.apigateway.api_gateway_stage import ApiGatewayStage
 from cloudrail.knowledge.context.aws.iam.policy_statement import PolicyStatement
 from cloudrail.knowledge.context.aws.resource_based_policy import ResourceBasedPolicy
 from cloudrail.knowledge.context.aws.apigateway.rest_api_gw_domain import RestApiGwDomain
@@ -24,6 +25,7 @@ class RestApiGw(ResourceBasedPolicy):
         api_gateway_type: One of EDGE, REGIONAL, PRIVATE.
         is_public: An indication on if this resource is accessible from the internet.
         api_gateway_methods: The ApiGatewayMethods associated with this gateway.
+        api_gw_stages: The stages associated with this REST API Gateway.
     """
     def __init__(self,
                  rest_api_gw_id: str,
@@ -37,6 +39,7 @@ class RestApiGw(ResourceBasedPolicy):
         self.api_gateway_type: ApiGatewayType = api_gateway_type
         self.method_settings: Optional[ApiGatewayMethodSettings] = None
         self.domain: Optional[RestApiGwDomain] = None
+        self.api_gw_stages: List[ApiGatewayStage] = []
 
         self.is_public: bool = None
         self.api_gateway_methods: List[ApiGatewayMethod] = []
